@@ -1,5 +1,5 @@
 package Rex::Dondley::ProcessTaskArgs ;
-$Rex::Dondley::ProcessTaskArgs::VERSION = '0.011';
+$Rex::Dondley::ProcessTaskArgs::VERSION = '0.012';
 use strict;
 use warnings;
 
@@ -131,7 +131,7 @@ Rex::Dondley::ProcessTaskArgs - easier Rex task argument handling
 
 =head1 VERSION
 
-version 0.011
+version 0.012
 
 =head1 SYNOPSIS
 
@@ -160,6 +160,10 @@ version 0.011
     my $params = process_task_args( \@_, key1, key2 [ 'default_value_for_key1' ]);
   };
 
+  # Params can also be returned in an array. The returned order is the same as
+  # the order of the list of available keys.
+  my ($one, $two, $three) = process_task_args( \@_, one => 1, two => 2, three => 3 );
+
 =head1 DESCRIPTION
 
 This module is designed to alleviate some of the pain of processing arguments
@@ -230,28 +234,45 @@ And the following command line command:
 
   rex some_task
 
-C<$params> will look like:
+C<$params> will be:
 
-  $params = { key1 => 'default_value_for_key1', key2 => undef };
+  { key1 => 'default_value_for_key1', key2 => undef };
 
 =head3 Example #2
 
 Given the following code:
 
   task 'another_task' => sub {
-    my $params = process_task_args( \@_, key1, key2 );
+    my ($key1, $key2) = process_task_args( \@_, key1, key2 [ 'default_value_for_key1' ] );
   };
 
 And the following command line command:
 
-  rex some_task some_value
+  rex some_task one two
 
-C<$params> will look like:
+C<$key1> will have a value of `one` and C<$key2> will have a value of `two`.
 
-  $params = { key1 => 'some_value', key2 => undef };
+This examples demonstrates that the function will return an array of values in
+an array context.
 
 =head3 Example #3
 
+Given the following code:
+
+  task 'another_task' => sub {
+    my $params = process_task_args( \@_, key1, key2 );
+  };
+
+And the following command line command:
+
+  rex some_task some_value
+
+C<$params> will be:
+
+  { key1 => 'some_value', key2 => undef };
+
+=head3 Example #4
+
 Given the following code:
 
   task 'another_task' => sub {
@@ -262,9 +283,9 @@ And the following command line command:
 
   rex some_task some_value another_value
 
-C<$params> will look like:
+C<$params> will be:
 
-  $params = { key1 => 'some_value', key2 => another_value };
+  { key1 => 'some_value', key2 => another_value };
 
 =head3 Example #4
 
@@ -278,11 +299,11 @@ And the following command line command:
 
   rex some_task some_value --key1=another_value
 
-C<$params> will look like:
+C<$params> will be:
 
-  $params = { key1 => 'another_value', key2 => 'some_value' };
+  { key1 => 'another_value', key2 => 'some_value' };
 
-=head3 Example #5
+=head3 Example #6
 
 Given the following code:
 
@@ -298,7 +319,12 @@ B<ERROR!> because C<key2> is required and it was not supplied.
 
 =head1 FUNCTIONS
 
-=head2 process_task_args($array_ref, $available_key1 [ => 1|0 ], $available_key2 [ => 1|0 ], ..., [ $array_ref ];
+=head2 my $params = process_task_args($array_ref, $available_key1 [ => 1|0 ], $available_key2 [ => 1|0 ], ..., [ $array_ref ];
+=function my @values = process_task_args($array_ref, $available_key1 [ => 1|0 ], $available_key2 [ => 1|0 ], ..., [ $array_ref ];
+
+The function will return values with keys as a hash reference in a scalar
+contect or as array with just the value depending on context. See L</SYNOPSIS>
+and exmaples above for usage instructions.
 
 =for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
